@@ -290,8 +290,6 @@ class SabayonInstall:
         if chroot is None:
             chroot = ""
         self._entropy.switch_chroot(chroot)
-        sys_settings_plg_id = etpConst['system_settings_plugins_ids']['client_plugin']
-        del self._settings[sys_settings_plg_id]['misc']['configprotectskip'][:]
 
     def install_package(self, atom, match = None, silent = False, fetch = False):
 
